/*
 * Copyright 2021 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.material.catalog.divider;

import io.material.catalog.R;

import android.os.Bundle;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import com.google.android.material.divider.MaterialDividerItemDecoration;
import io.material.catalog.feature.DemoFragment;

/** Demo of the MaterialDividerItemDecoration. */
public class DividerItemDecorationDemoFragment extends DemoFragment {

  private RecyclerView recyclerView;
  private DividerAdapter adapter;
  private RecyclerView.LayoutManager layoutManager;

  @Nullable
  @Override
  public View onCreateDemoView(
      @NonNull LayoutInflater layoutInflater,
      @Nullable ViewGroup viewGroup,
      @Nullable Bundle bundle) {
    View view =
        layoutInflater.inflate(
            R.layout.cat_divider_recyclerview_fragment, viewGroup, /* attachToRoot */ false);

    recyclerView = view.findViewById(R.id.divider_recyclerview);
    layoutManager = new LinearLayoutManager(getContext(), LinearLayoutManager.VERTICAL, false);
    recyclerView.setLayoutManager(layoutManager);

    MaterialDividerItemDecoration divider =
        new MaterialDividerItemDecoration(getContext(), LinearLayoutManager.VERTICAL);
    recyclerView.addItemDecoration(divider);

    adapter = new DividerAdapter();
    recyclerView.setAdapter(adapter);

    return view;
  }

  /** A RecyclerView adapter. */
  private static final class DividerAdapter
      extends RecyclerView.Adapter<DividerAdapter.MyViewHolder> {

    /** Provide a reference to the views for each data item. */
    private static class MyViewHolder extends RecyclerView.ViewHolder {

      TextView item;

      public MyViewHolder(@NonNull View itemView) {
        super(itemView);
        item = (TextView) itemView;
      }
    }

    public DividerAdapter() {}

    @NonNull
    @Override
    public MyViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
      View view =
          LayoutInflater.from(parent.getContext())
              .inflate(R.layout.cat_divider_recyclerview_item, parent, false);
      return new MyViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull MyViewHolder holder, int position) {
      holder.item.setText(
          holder.item.getResources().getString(R.string.cat_divider_item_text, position + 1));
    }

    @Override
    public int getItemCount() {
      return 30;
    }
  }
}
